@@ -5,14 +5,14 @@ class Emitter(object):
         self._events = {}
 
     def on(self, name, fn):
-        self._events.setdefault(name, []).append(fn)
+        self._events.setdefault(name, set([])).add(fn)
         return self
 
     def fire(self, name, data):
-        for fn in self._events.get("*", []):
+        for fn in self._events.get("*", set([])):
             fn(name, data)
 
-        for fn in self._events.get(name, []):
+        for fn in self._events.get(name, set([])):
             fn(data)
 
-        return self
\ No newline at end of file
+        return self
